var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { nameof } from "ts-simple-nameof";
import { AsyncLock } from "../AsyncLock";
import { DependencyContainer } from "../DependencyContainer";
import { Event } from "../Event";
export class AppStateService {
    constructor() {
        this._syncLock = new AsyncLock();
        this._isInFouces = true;
        this._canHibernate = true;
        this._returnedFromSuspension = false;
        this._serviceName = nameof(AppStateService);
        this._onReturnedFromSuspensionEvent = new Event();
        this._onSuspendedEvent = new Event();
        this._onEnterLowPowerModeEvent = new Event();
        this._onExitLowPowerModeEvent = new Event();
        this._onBackButtonPressedEvent = new Event();
        this._onForwardButtonPressedEvent = new Event();
    }
    _constructor() {
        if (navigator.userAgent.match(/Safari/i) != null && !navigator.mediaDevices) {
            window.addEventListener("onblur", () => {
                if (!this._isInFouces)
                    return;
                this._isInFouces = false;
                this.Suspend();
            });
            window.addEventListener("onfocus", () => {
                if (this._isInFouces)
                    return;
                this._isInFouces = true;
                this.ReturnFromSuspension();
            });
        }
        else {
            window.addEventListener("visibilitychange", () => __awaiter(this, void 0, void 0, function* () {
                yield this._syncLock.WaitForLockAsync();
                this._syncLock.Lock();
                if (this.IsHidden())
                    this.Suspend();
                else
                    this.ReturnFromSuspension();
                this._syncLock.Unlock();
            }));
        }
    }
    Suspend() {
        var _a;
        if (!this.IsHibernationAllowed())
            return;
        this._returnedFromSuspension = false;
        this._onSuspendedEvent.Invoke();
        (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Warning(AppStateService, "App switched to background");
    }
    ReturnFromSuspension() {
        var _a;
        if (!this.IsHibernationAllowed())
            return;
        this._returnedFromSuspension = true;
        this._onReturnedFromSuspensionEvent.Invoke();
        (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Warning(AppStateService, "App switched to foreground");
    }
    EnterLowPowerMode() {
        this._onEnterLowPowerModeEvent.Invoke();
    }
    ExitLowPowerMode() {
        this._onExitLowPowerModeEvent.Invoke();
    }
    IsWorkingInWebView() {
        if (navigator.userAgent.match(/Safari/i) != null) {
            if (navigator.mediaDevices)
                return false;
            else
                return true;
        }
        else if (window.hasOwnProperty('Android ')) {
            return true;
        }
        else {
            return false;
        }
    }
    IsHidden() {
        return document.hidden;
    }
    IsActive() {
        return !this.IsHidden();
    }
    IsInBackground() {
        return this.IsHidden();
    }
    ReturnedFromSuspension() {
        return this._returnedFromSuspension;
    }
    IsHibernationAllowed() {
        return this._canHibernate;
    }
    DisallowHibernation() {
        this._canHibernate = false;
    }
    AllowHibernation() {
        this._canHibernate = true;
    }
    OnReturnedFromSuspension() {
        return this._onReturnedFromSuspensionEvent;
    }
    OnSuspended() {
        return this._onSuspendedEvent;
    }
    OnEnterLowPowerMode() {
        return this._onEnterLowPowerModeEvent;
    }
    OnExitLowPowerMode() {
        return this._onExitLowPowerModeEvent;
    }
    OnBackButtonPressed() {
        return this._onBackButtonPressedEvent;
    }
    OnForwardButtonPressed() {
        return this._onForwardButtonPressedEvent;
    }
    GetServiceName() {
        return this._serviceName;
    }
}
//# sourceMappingURL=AppStateService.js.map