var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { ResponseResult } from '../FieldChangeResult';
import { Coordinates, SetGeolocationResponseCode } from './IGeolocationService';
import { DataFrame, Method, Status } from '../../DataFrame';
import { Api } from '../../Api';
import { ExalusConnectionService } from '../ExalusConnectionService';
import { nameof } from 'ts-simple-nameof';
export class GeolocationService {
    constructor() {
        this._connection = null;
        this._serviceName = nameof(GeolocationService);
    }
    __constructor() {
        this._connection = Api.Get(ExalusConnectionService);
    }
    IsControllerGeolocationSetAsync() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            let response = yield ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.SendAndWaitForResponseAsync(new IsGeolocationSetRequest(), 15000, true));
            switch (response === null || response === void 0 ? void 0 : response.Status) {
                case Status.OK:
                    return response === null || response === void 0 ? void 0 : response.Data;
                default:
                    return response === null || response === void 0 ? void 0 : response.Status;
            }
        });
    }
    GetCurrentGeolocationAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
                window.navigator.geolocation.getCurrentPosition(position => {
                    resolve(position);
                }, error => {
                    resolve(error);
                });
            }));
        });
    }
    SetControllerGeolocationAsync(location) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            let req = new SetCoordinatesRequest();
            req.Data.Latitude = location.Latitude;
            req.Data.Longitude = location.Longitude;
            let response = yield ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.SendAndWaitForResponseAsync(req, 15000, true));
            switch (response === null || response === void 0 ? void 0 : response.Status) {
                case Status.OK:
                    return new ResponseResult(SetGeolocationResponseCode.OK, "");
                case Status.NoPermissionToPerformThisOperation:
                case Status.NoPermissionsToCallGivenResource:
                    return new ResponseResult(SetGeolocationResponseCode.NoPermissions, "");
                case Status.UserIsNotLoggedIn:
                    return new ResponseResult(SetGeolocationResponseCode.UserIsNotLoggedIn, "");
                default:
                    return new ResponseResult(SetGeolocationResponseCode.UnknownError, "");
            }
        });
    }
    GetControlllerGeolocationAsync() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            let response = yield ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.SendAndWaitForResponseAsync(new GetSetCoordinatesRequest(), 15000, true));
            switch (response === null || response === void 0 ? void 0 : response.Status) {
                case Status.OK:
                    return response === null || response === void 0 ? void 0 : response.Data;
                default:
                    return response === null || response === void 0 ? void 0 : response.Status;
            }
        });
    }
    GetServiceName() {
        return this._serviceName;
    }
}
class IsGeolocationSetRequest extends DataFrame {
    __constructor() {
        this.Resource = "/geolocation/isset";
        this.Method = Method.Get;
    }
}
class GetSetCoordinatesRequest extends DataFrame {
    __constructor() {
        this.Resource = "/geolocation/get";
        this.Method = Method.Get;
    }
}
class SetCoordinatesRequest extends DataFrame {
    constructor() {
        super(...arguments);
        this.Data = new Coordinates();
    }
    __constructor() {
        this.Resource = "/geolocation/save";
        this.Method = Method.Put;
    }
}
//# sourceMappingURL=GeolocationService.js.map